@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 from .dot_env import load_env, load_dotenv
-from .env_wrapper import Env
+from .env_wrapper import Env, env
 
 
 __all__ = (
     'load_env',
     'load_dotenv',
     'Env',
+    'env',
 )
